@@ -44,12 +44,16 @@ def create_timeseries_model_workflow(name="model", exp_info=None):
                          ["timeseries", "realign_file", "artifact_file"],
                          "modelsetup")
 
+    # For some nodes, make it possible to request extra memory
+    mem_request = {"qsub_args": "-l h_vmem=%dG" % exp_info["memory_request"]}
+
     # Use film_gls to estimate the timeseries model
     modelestimate = MapNode(fsl.FILMGLS(smooth_autocorr=True,
                                         mask_size=5,
                                         threshold=100),
                             ["design_file", "in_file"],
                             "modelestimate")
+    modelestimate.plugin_args = mem_request
 
     # Run the contrast estimation routine
     contrastestimate = MapNode(fsl.ContrastMgr(),
@@ -59,6 +63,7 @@ def create_timeseries_model_workflow(name="model", exp_info=None):
                                 "param_estimates",
                                 "sigmasquareds"],
                                "contrastestimate")
+    contrastestimate.plugin_args = mem_request
 
     # Compute summary statistics about the model fit
     modelsummary = MapNode(ModelSummary(),
@@ -66,6 +71,7 @@ def create_timeseries_model_workflow(name="model", exp_info=None):
                             "timeseries",
                             "pe_files"],
                            "modelsummary")
+    modelsummary.plugin_args = mem_request
 
     # Save the experiment info for this run
     # Save the experiment info for this run
@@ -302,7 +308,8 @@ class ModelSetup(BaseInterface):
             fs, pxx_unfilt = signal.welch(y_unfilt, 1. / tr, nperseg=ntp)
 
             # Draw the spectral density
-            f, ax = plt.subplots(figsize=(9, 3))
+            with sns.axes_style("whitegrid"):
+                f, ax = plt.subplots(figsize=(9, 3))
             ax.fill_between(fs, pxx_unfilt, color="#C41E3A")
             ax.axvline(1.0 / exp_info["hpf_cutoff"], c=".3", ls=":", lw=1.5)
             ax.fill_between(fs, pxx_filt, color=".5")
